#
# spec file for package proton-vpn
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}%{!?sle15_python_module_pythons:%define pythons python3}
Name:           proton-vpn
Version:        4.9.6
Release:        1.1
Summary:        Official Proton VPN client
License:        GPL-3.0-or-later
Group:          Productivity/Networking/Security
URL:            https://github.com/ProtonVPN/proton-vpn-gtk-app
Source0:        https://github.com/ProtonVPN/proton-vpn-gtk-app/archive/refs/tags/%{version}.tar.gz
BuildRequires:  %{python_module dbus-python}
BuildRequires:  %{python_module distro}
BuildRequires:  %{python_module gobject}
BuildRequires:  %{python_module packaging}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module proton-core}
BuildRequires:  %{python_module proton-vpn-api-core >= 0.42.1}
BuildRequires:  %{python_module proton-vpn-network-manager >= 0.12.13}
BuildRequires:  %{python_module pycairo}
BuildRequires:  %{python_module pytest-cov}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module requests}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  pkgconfig(gobject-introspection-1.0)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(libnotify)
Requires:       %{pythons}-dbus-python
Requires:       %{pythons}-distro
Requires:       %{pythons}-gobject
Requires:       %{pythons}-packaging
Requires:       %{pythons}-proton-core
Requires:       %{pythons}-proton-vpn-api-core >= 0.42.1
Requires:       %{pythons}-proton-vpn-network-manager >= 0.12.13
Requires:       %{pythons}-pycairo
Requires:       %{pythons}-requests
Requires:       gtk3
Suggests:       libappindicator-gtk3
Conflicts:      protonvpn-gui
Provides:       protonvpn-app = %{version}
BuildArch:      noarch

%description
The Proton VPN client is easy to use and packed with advanced features
carefully designed to improve your online security.

%prep
%autosetup -n proton-vpn-gtk-app-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%fdupes %{buildroot}%{python_sitelib}

install -Dm0644 rpmbuild/SOURCES/proton-vpn-logo.svg %{buildroot}%{_datadir}/icons/hicolor/scalable/apps/proton-vpn-logo.svg
install -Dm0644 ./rpmbuild/SOURCES/protonvpn-app.desktop %{buildroot}%{_datadir}/applications/proton-vpn.desktop

%files
%doc README.md
%license LICENSE COPYING.md
%{_bindir}/protonvpn-app
%{_datadir}/applications/proton-vpn.desktop
%{_datadir}/icons/hicolor/scalable/apps/proton-vpn-logo.svg
%{python_sitelib}/proton
%{python_sitelib}/proton_vpn_gtk_app-%{version}.dist-info

%changelog
* Tue Apr  8 2025 Richard Rahl <rrahl0@opensuse.org>
- update to 4.9.6:
  * nothing of relevance
- update spec file:
  * switch to autosetup
  * remove update-dekstop-files
  * switch to pyproject macros
  * use sle15 macros for defining which python version
* Mon Mar 31 2025 Szymon Scholz <raspherdev@pm.me>
- Update package to 4.9.5
  * [VPNLINUX-1066] Add custom dns setting to settings window.
  * [VPNLINUX-1080] Settings not opening due to early access toggle crashing.
  * [VPNLINUX-1076] Improve custom DNS.
  * [VPNLINUX-1055] Added semgrep scanning to CI
  * [VPNLINUX-1070] Introduce pop-up for conflicting features (netshield/custom dns)
  * [VPNLINUX-1086] Add reconnection warning when enabling custom DNS.
  * [VPNLINUX-1074] Drop support for Ubuntu 20.04
  * [VPNLINUX-1089] Fix kill switch leak on quit.
  * [VPNLINUX-1096] Add final URL to 'learn more' link buttons.
  * [VPNLINUX-1106] Update release package version used for beta toggle
  * [VPNLINUX-1079] Ensure UI is using latest feature flags after login.
  * [VPNLINUX-1132] Ensure app does not crash when attempting to logout after doing a search.
  * [VPNLINUX-1128] Display forwarded port if available.
  * [VPNLINUX-1128] Only display port if environment variable is set.
  * [VPNLINUX-1134] Display server load in search results
  * [VPNLINUX-1117] Include beta branch on version metadata.
  * [VPNLINUX-1116] Remove code related to old feature flags.
  * [VPNLINUX-1145] Re-implement tests and clean-up code.
  * [VPNLINUX-1144] Replace deprecated method.
  * Remove save_setting when building UI.
  * [VPNLINUX-949] Fix cancel connection button
  * [VPNLINUX-949] update changelog
  * [VPNLINUX-1129] Show port forwarding desktop notification
  * [VPNLINUX-1169] Switch DisplayPortForwarding env var to Feature Flag
  * [VPNLINUX-1168] Customize Port Forwarding notification
  * [VPNLINUX-1167] Update api-core dependency
  * [VPNLINUX-1168] Minor changes to wording of port forwarding user interface
  * [VPNLINUX-1181] add linux referral to sign-up URL
  * [VPNLINUX-1176] Fix crash when quitting the app while connected and PF is enabled
* Tue Nov 12 2024 Alexandre Vicenzi <alexandre.vicenzi@suse.com>
- Update package to 4.7.4:
  * Fix bug when opening settings window, if installed via unsupported methods the early access toggle would crash.
  * Fix bug when opening the settings window and advanced kill switch is enabled the settings would crash.
  * Update kill switch and protocol label, clarifying that they can be switched only when disconnected from vpn
  * Fix introduced regression as it was no longer deactivating the selection of protocol and kill switch while being connected to VPN
  * Add start-app-minimized to settings window
  * Remove killswitch dependencies in setup.py as packages have been deprecated
  * Merge community MR to allow the app to start minimized based on CLI arguments
  * Drop secret service package
  * Drop logger package
  * Fix regression when moving refreshers
  * Move refreshers to core API
  * Add back scheduler after memory leak fix
  * When toggling IPv6 ensure that user is notified that a reconnection is necessary and prevent certificate refresh
  * Add IPv6 toggle to settings window
  * Switch back to old scheduler due to memory leak in new one
  * Show VPN accelerator setting disabled to free users
  * Don't display reconnect message when connected via WireGuard protocol and settings are switched
  * Changes due to api-core refactor
  * Request connection features via local agent if available.
  * Added a MaximumSessionsReached event to the list of events that can be emitted.
  * Update package URL used by early release settings toggle.
  * Refresh certificate whenever the app receives an expired certificate event.
  * Only display WireGuard protocol if already selected or if feature flag is enabled, otherwise hide it.
  * Fix wrong imports after core api refactor.
  * Implement and refresh feature flags.
  * When early access is toggled, ensure that repo package can be downloaded, otherwise display error message.
  * Add early access toggle to settings window.
  * Move the scripts for generating the changelogs into a separate repo.
  * Only allow kill switch settings modifications when disconnected from the VPN.
  * Log the user out on session expired error while updating certificate.
  * Implement exponential backoff when retrying to refresh certificate.
  * Fix task scheduler after suspending/resuming the computer.
  * Refactor settings to ensure the settings file isn't created when we retrieve it.
  * Disable protocol selection if user is connected to vpn.
- Remove setup-data-files.patch
* Wed May 22 2024 Alexandre Vicenzi <alexandre.vicenzi@suse.com>
- Add setup-data-files.patch to fix erroneous files being installed
- Update package
  * 4.3.2
  - We no longer call UsageReporting.init to initialize UsageReporting.
  - Only initialize sentry on first enable.
  - Forward SSL_CERT_FILE environment variable to sentry.
  * 4.3.1
  - Ensure behavioral consistency when opening settings window across different distributions
  - Update label alignment on disable kill switch widget at login
  - Missed the minimum python3-proton-vpn-api-core version in build_packages.py
  - Switch to using sessions module that is now bundled with vpn-api-core
  - Update wireguard certificate request when settings are changed
  - Add connection features to the wireguard certificate request
  - Periodically refresh certificate
  * 4.3.0
  - Provide the possibility to disable Kill Switch if user is logged out and Kill Switch is set to permanent
  - Ensure that protocol list in settings UI is properly capitalized and alphabetically ordered
  - Anonymous crash reports are now sent by default, this can be disabled in the settings
  - Change how we build debian and rpm packages. We now depend on a single versions.yml file to build everything
  - Increase minimum number of characters required for bug report description
* Thu Mar 21 2024 Alexandre Vicenzi <alexandre.vicenzi@suse.com>
- Update to 4.2.0
  * Add overlay when connecting to server
  * Upon logging out or quitting, inform the user about the kill switch status
  * Apply kill switch settings immediately
  * Add permanent option to kill switch setting
  * Fix minor bug in country row initialization
* Fri Feb  9 2024 Alexandre Vicenzi <alexandre.vicenzi@suse.com>
- Initial revision
